@@ -1,7 +1,7 @@
 package Panda::Export;
 use 5.012;
 
-our $VERSION = '2.2.1';
+our $VERSION = '2.2.2';
 
 =head1 NAME
 
@@ -159,6 +159,8 @@ If you specify wrong sub or const name in import list an exception will also be
 
 =head1 C FUNCTIONS
 
+Functions marked with C<[pTHX]> must receive C<aTHX_> as a first arg.
+
 The whole API is thread-safe.
 
     struct constant_t {
@@ -167,60 +169,60 @@ The whole API is thread-safe.
         const char* svalue;
     };
 
-=head4 void create_constant (HV* stash, SV* name, SV* value)
+=head4 void create_constant (HV* stash, SV* name, SV* value) [pTHX]
 
-=head4 void create_constant (HV* stash, const char* name, const char* value)
+=head4 void create_constant (HV* stash, const char* name, const char* value) [pTHX]
 
-=head4 void create_constant (HV* stash, const char* name, int64_t value)
+=head4 void create_constant (HV* stash, const char* name, int64_t value) [pTHX]
 
 Creates constant with name C<name> and value C<value> in package C<stash>.
 Croaks if package already has sub/constant with that name.
 
-=head4 void create_constant (HV* stash, constant_t constant)
+=head4 void create_constant (HV* stash, constant_t constant) [pTHX]
 
 If constant.svalue is null, creates numeric constant (constant.value), otherwise creates string constant (constant.svalue) 
 
-=head4 void create_constants (HV* stash, HV* constants)
+=head4 void create_constants (HV* stash, HV* constants) [pTHX]
 
 Creates a constant for each key/value pair in hash C<constants>.
 
-=head4 void create_constants (HV* stash, SV** list, size_t items)
+=head4 void create_constants (HV* stash, SV** list, size_t items) [pTHX]
 
 Creates a constant for each key/value pair in array C<list>.
 It means that list[0] is a key, list[1] is a value, list[2] is a key, etc...
 Array should not contain empty slots and empty keys or it will croak.
 If elements count is odd, last element is ignored. You must pass the size of C<list> in C<items>.
 
-=head4 void create_constants (HV* stash, constant_t* list, size_t items = MAX_ITEMS)
+=head4 void create_constants (HV* stash, constant_t* list, size_t items = MAX_ITEMS) [pTHX]
 
 Creates a constant for each key/value pair in array C<list>.
 Stops processing list if discovered an element with element.name == NULL. Therefore you must either pass a valid C<items>, or
 end your list with "{NULL}" value.
 
-=head4 void export_sub (HV* from, HV* to, SV* name)
+=head4 void export_sub (HV* from, HV* to, SV* name) [pTHX]
 
-=head4 void export_sub (HV* from, HV* to, const char* name)
+=head4 void export_sub (HV* from, HV* to, const char* name) [pTHX]
 
 Exports sub/constant with name C<name> from package C<from> to package <to>.
 
-=head4 void export_constants (HV* from, HV* to)
+=head4 void export_constants (HV* from, HV* to) [pTHX]
 
 Exports all constants from package C<from> to package <to>.
 
-=head4 void export_subs (HV* from, HV* to, AV* list)
+=head4 void export_subs (HV* from, HV* to, AV* list) [pTHX]
 
 Exports contants/subs with names in C<list>.
 
-=head4 void export_subs (HV* from, HV* to, SV** list, size_t items)
+=head4 void export_subs (HV* from, HV* to, SV** list, size_t items) [pTHX]
 
 Exports contants/subs with names in C<list>. You must pass the size of C<list> in C<items>.
 
-=head4 void export_subs (HV* from, HV* to, const char** list, size_t items = MAX_ITEMS)
+=head4 void export_subs (HV* from, HV* to, const char** list, size_t items = MAX_ITEMS) [pTHX]
 
 Exports contants/subs with names in C<list>. Stops processing list if discovered NULL value in list.
 Therefore you must either pass a valid C<items>, or end your list with NULL value.
 
-=head4 AV* constants_list (HV* stash)
+=head4 AV* constants_list (HV* stash) [pTHX]
 
 Returns the list of all constants defined in package C<stash> as a perl array.
 
